# sombra-engine 

Game Engine made in Python on top of the pyglet framework (work in progress).

## Planned features

- 3D models through glTF format (and limited support for OBJ)
- OpenGL Renderer and GLSL shaders
- Skeletal animations
- Pathfinding
- Rigid body physics
- Particle systems
- Terrain rendering
- UI library with shaders support (through [pudu-ui](https://github.com/sombra-studio/pudu-ui))

![screenshot](https://raw.githubusercontent.com/sombra-studio/sombra-engine/refs/heads/main/docs/screenshot.png)

You can get the OBJ model of Yoda from [here](https://graphics.cs.utah.edu/courses/cs6610/spring2022/prj04/yoda.zip)
